#
# spec file for package procenv
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           procenv
Version:        0.60
Release:        1.11
Summary:        Process Environment Dump Tool
License:        GPL-3.0-or-later
Group:          System/Base
URL:            https://launchpad.net/procenv/
Source:         https://github.com/jamesodhunt/procenv/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  libcap-devel
BuildRequires:  libnuma-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  pkgconfig

%description
procenv is a tool that dumps all attributes of its environment. It can be run
as a test tool, to understand what environment a process runs in and for system
comparison.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc AUTHORS NEWS README.md TODO
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Wed Jul 14 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.60:
  * Bump output format version (should have been done for 0.58).
  * snap: Add missing staging packages.
  * autoconf: Fix AppArmor and SELinux detection
    Bug fix that necessitated a new release: previously, the security
    context displayed with --misc could show as "unknown" due to a
    bug in configure.ac's detection code.
  * docs: Add snap details to README.
* Wed Jul 14 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.59:
  * doc improvements (README and man page).
  * snap: Add snapcraft config file
  * --sysconf:
    + Display output in order.
    + Removed duplicate entry for _SC_EXPR_NEST_MAX.
    + Added new entries for:
  - _SC_2_PBS_CHECKPOINT
  - _SC_SS_REPL_MAX
  - _SC_STREAMS
  - _SC_TRACE_EVENT_NAME_MAX
  - _SC_TRACE_NAME_MAX
  - _SC_TRACE_SYS_MAX
  - _SC_TRACE_USER_EVENT_MAX
  - _SC_XOPEN_STREAMS
  * --misc: BUG fix: Check for PR_GET_UNALIGN prctl, not PR_GET_UNALIGNED.
  * --namespaces: BUG fix: Don't fully resolve namespace links to handle new
  pid_for_children and time_for_children namespaces.
* Mon Jun 28 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.58:
  * darwin: Support --libs.
  * darwin: Support AF_LINK for --network.
  * docs: Remove TOC.
* Mon Jun 21 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.57:
  * Add macports installation instructions.
  * --timezone: Enabled for Darwin, FreeBSD, NetBSD and OpenBSD.
  * --clocks: Add CLOCK_BOOTTIME_ALARM, CLOCK_PROCESS_CPUTIME_ID
    and CLOCK_REALTIME_ALARM to output.
  * darwin: Enabled --clocks.
* Mon Jun 14 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.56:
  * tidy: compact and align structs for memory size and performance.
  * darwin: Add memory details (total, free, wired, unused,
    active and inactive memory).
  * doc improvements.
* Fri Apr  9 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.55:
  * Documentation improvements.
  * Hurd build fixes:
  - Disable detailed memory reporting as sysinfo() not available).
  - Fixed detection for modern versions of Hurd.
* Wed Mar 17 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.54:
  * --capabilities: Added new capabilities:
  * CAP_BPF
  * CAP_CHECKPOINT_RESTORE
  * CAP_PERFMON
  * --clocks: Add CLOCK_TAI.
  * --memory: Add details of total and available memory and swap.
    Requires the libsysinfo package on *BSD.
  * --process: Fixed nasty bug (infinite loop) on *BSD if any of
    the following sysconf's are set:
  * security.bsd.see_other_uids=0
  * security.bsd.see_other_gids=0
  * kern.randompid=1
  * Fix compiler flag checking in the configure script.
* Tue Mar  2 2021 Michael Vetter <mvetter@suse.com>
- Run spec-cleaner
* Tue Mar  2 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.53:
  * Really fix FreeBSD capabilities/capsicum build.
* Mon Mar  1 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.52:
  * Fix GCC-10 build when used with -Werror=format-overflow
  * Fix FreeBSD capabilities/capsicum build
* Thu Sep 12 2019 mvetter@suse.com
- Update to 0.51:
  * Fixed failure scenario identified by scan-build(1).
  * Fixed GNU Hurd detection.
  * Fixed building without libcap.
  * Fix compiler warnings for gcc9.
* Wed Oct 18 2017 aavindraa@gmail.com
- Update to 0.50
- Packaging changes
  - Point to new github url
  - Lint spec file
  - Drop procenv-remove_date.patch
  - remove ChangeLog during build, as it's now zeroed out
* Sun Aug  2 2015 mpluskal@suse.com
- Update to 0.36
  * see attached ChangeLog for details
- Cleanup spec file with spec-clener
- Refresh procenv-remove_date.patch
* Sun Feb  2 2014 pascal.bleser@opensuse.org
- update to 0.31:
  * FIX: Environment display could cause a crash
  * FIX: Last attacher process in shared memory display on Linux incorrectly
    showed the current process name rather than the last
- changes from 0.28:
  * FEATURE: '--cpu' now displays processor affinity details (LP: #1251209)
  * FEATURE: --memory/-Y added to display NUMA memory details
- changes from 0.27:
  * Added IPC options '--shared-memory', '--semaphores' and '--message-queues'
  * Made default text output highly structured
  * Added ability to produce output in XML, JSON and "breadcrumb" (including
    CSV) formats
  * Added ability to specify indent amount, indent character and separators
    (via command-line or environment variable)
* Wed Aug 28 2013 pascal.bleser@opensuse.org
- update to 0.26:
  * added ability to show all arguments (-A/--arguments)
  (useful when using --exec)
  * added ability to display network details (-N/--network)
  * corrected output sort order
  * mount details now include block, inode and fsck details
- (0.25 only contained non-Linux specific changes)
* Sat Jun 29 2013 pascal.bleser@opensuse.org
- update to 0.24: (build fixes)
- changes from 0.23:
  * tolerate Linux environments where /proc is not mounted
- changes from 0.22:
  * added --platform option which contains some information that was formally
    in --misc output, but also now includes the number of "architecture bits"
    (executable bits) and the programming model for the platform (such as
    LP32/ILP64)
* Sun Apr  7 2013 pascal.bleser@opensuse.org
- initial version (0.21)
